package jx.cn.escort.ui.activity




import android.content.Context
import android.content.SharedPreferences
import android.os.Bundle
import android.view.animation.Animation
import android.view.animation.RotateAnimation
import androidx.appcompat.app.AppCompatActivity
import androidx.lifecycle.lifecycleScope
import com.xuexiang.xui.XUI
import com.xuexiang.xui.widget.dialog.materialdialog.MaterialDialog
import com.xuexiang.xui.widget.toast.XToast
import jx.cn.escort.databinding.ActivityLoginBinding
import jx.cn.escort.extension.ExtensionBinding.Companion.binding
import jx.cn.escort.utils.ActivityUtils
import kotlinx.coroutines.delay
import kotlinx.coroutines.launch
import org.koin.core.component.KoinComponent
import org.koin.core.component.inject


 class LoginActivity : AppCompatActivity(), KoinComponent {


    private val mContext: Context   by  inject()

    private val mBinding: ActivityLoginBinding by binding<ActivityLoginBinding>()


    private val defaultSharedPreferences: SharedPreferences = androidx.preference.PreferenceManager.getDefaultSharedPreferences(mContext)




    override fun onCreate(savedInstanceState: Bundle?) {
        XUI.initTheme(this@LoginActivity);
        super.onCreate(savedInstanceState)
        setContentView(mBinding.root)



        mBinding.btnLoginAction.setOnClickListener {

            val account: String = mBinding.loginAccount.text.toString().trim()
            val password: String = mBinding.loginPassword.text.toString().trim()

            if (account.isBlank()) {
                XToast.info(this@LoginActivity, "请输入账号").show();
                return@setOnClickListener
            }
            if (password.isBlank()) {
                XToast.info(this@LoginActivity, "请输入密码").show();
                return@setOnClickListener
            }

            var isValidateAccount=false
            accountRegex.forEach{ it->
                if(!account.matches(it)){
                    isValidateAccount=true
                }
            }

            if(!isValidateAccount) {
                XToast.info(this@LoginActivity, "未开户").show();
                return@setOnClickListener
            }

            if(password.length < 6) {
                XToast.info(this@LoginActivity, "密码小于6位").show();
                return@setOnClickListener
            }

            if(!password.equals("123456", ignoreCase = true)) {
                XToast.info(this@LoginActivity, "密码不正确").show();
                return@setOnClickListener
            }


            lifecycleScope.launch {
                mBinding.loginTitle.text = "加载中..."
                var density=resources.displayMetrics.density
                var drawable=resources.getDrawableForDensity(jx.cn.escort.R.drawable.ic_login_loding,65*density.hashCode(),null)

                mBinding.btnLoginAction.icon=drawable

                val rotateAnimation=RotateAnimation(0f,360f,Animation.RELATIVE_TO_SELF,0.5f,Animation.RELATIVE_TO_SELF,0.5f)
                rotateAnimation.setRepeatCount(Animation.INFINITE);
                rotateAnimation.duration=1000L
                rotateAnimation.fillAfter=true
                mBinding.btnLoginAction.startAnimation(rotateAnimation)

                delay(1000L)
                defaultSharedPreferences.edit().putString("isAuth", "是").apply()
                defaultSharedPreferences.edit().putString("account", account).apply()
                defaultSharedPreferences.edit().putString("password", password).apply()
                if(account.matches(accountRegex[0])){
                    defaultSharedPreferences.edit().putString("role", "网点授权人员").apply()
                }else{
                    defaultSharedPreferences.edit().putString("role", "押运授权人员").apply()
                }
                ActivityUtils.startActivity(this@LoginActivity,MainActivity::class.java)
                finish()

            }
        }
    }


     companion object {
         private val accountRegex:List<Regex>
             get() {
                 return  mutableListOf<Regex>(
                     Regex("^BOfficer\\d+"),
                     Regex("^EOfficer\\d+")
                 )
             }

         @JvmStatic fun toAccountRegex():List<Regex>{

                 return accountRegex;
             }


     }



}