package jx.cn.escort.ui.widget

import android.content.Context
import android.graphics.*
import android.util.Log
import android.view.View


class CircleProgressView(context: Context) : View(context) {


    private var bottomCirclePaint: Paint? = null //底部圆画笔
    private var paintWidth = 0f //底部圆外扩半径
    private var centerPoint: PointF? = null //中心点

    private var mInnerPaint: Paint? = null //内环
    private var mTextPaint: Paint? = null //文字
    private var InnerRectF: RectF? = null //内环 位置

    private var mProgressPaint: Paint? = null //内环 进度

    private var progress = 0 //进度

    private var progressStartColor = "#b3e6fe" //进度渐变开始颜色
    private var progressEndColor = "#04adfb" //进度渐变结束颜色

    fun setProgressStartColor(progressStartColor: String) {
        this.progressStartColor = progressStartColor
    }

    fun setProgressEndColor(progressEndColor: String) {
        this.progressEndColor = progressEndColor
    }



    override fun onMeasure(widthMeasureSpec: Int, heightMeasureSpec: Int) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec)
    }

    override fun onDraw(canvas: Canvas) {
        super.onDraw(canvas)
        initPaint()
        var text = "未检测到人脸"
        var angle = progress.toFloat() * 330 / 100
        if (angle > 330) {
            angle = 330f
        } else if (angle > 30) {
            text = "请保持不动"
        }
        val width = mTextPaint!!.measureText(text)

        canvas.drawText(text, centerPoint!!.x - width / 2, InnerRectF!!.top + 100, mTextPaint!!)

        canvas.drawCircle(centerPoint!!.x, centerPoint!!.y, (paintWidth * 3 / 2 + paintWidth / 2), bottomCirclePaint!!)
        canvas.drawArc(InnerRectF!!, 105f, 330f, false, mInnerPaint!!)
        canvas.drawArc(InnerRectF!!, 105f, angle, false, mProgressPaint!!)
    }

    /**
     * 初始化画笔
     */
    private fun initPaint() {
        if (bottomCirclePaint == null) {
            bottomCirclePaint = Paint()
            bottomCirclePaint!!.color = Color.WHITE
            bottomCirclePaint!!.isAntiAlias = true //抗锯齿
            bottomCirclePaint!!.style = Paint.Style.STROKE //不加这个不显示
        }
        if (mInnerPaint == null) {
            mInnerPaint = Paint()
            mInnerPaint!!.color = Color.GRAY
            mInnerPaint!!.alpha = 60
            //抗锯齿
            mInnerPaint!!.isAntiAlias = true
            //画笔宽度
            mInnerPaint!!.strokeWidth = 12f
            //防抖动
            mInnerPaint!!.isDither = true
            //设置状态
            mInnerPaint!!.style = Paint.Style.STROKE
            //头部小圆点
            mInnerPaint!!.strokeCap = Paint.Cap.ROUND
        }
        if (mTextPaint == null) {
            mTextPaint = Paint()
            mTextPaint!!.color = Color.WHITE
            mTextPaint!!.textSize = 38f
        }
        if (mProgressPaint == null) {
            mProgressPaint = Paint()
            mProgressPaint!!.color = Color.BLUE
            //抗锯齿
            mProgressPaint!!.isAntiAlias = true
            //画笔宽度
            mProgressPaint!!.strokeWidth = 12f
            //防抖动
            mProgressPaint!!.isDither = true
            //设置状态
            mProgressPaint!!.style = Paint.Style.STROKE
            //头部小圆
            mProgressPaint!!.strokeCap = Paint.Cap.ROUND
        }

        if (centerPoint == null) {
            centerPoint = PointF()
        }
        if (paintWidth < 1) {
            paintWidth = 180f
            centerPoint!!.x = (width / 2).toFloat()
            centerPoint!!.y = (height / 2).toFloat()
            initRectF()
        }
        Log.e("TEST", "onMeasure$paintWidth")
        bottomCirclePaint!!.strokeWidth = paintWidth
    }

    private fun initRectF() {
        if (InnerRectF == null) {
            InnerRectF = RectF()
        }
        val radius = paintWidth * 3 / 2 + 6
        InnerRectF!!.top = centerPoint!!.y - radius
        InnerRectF!!.left = centerPoint!!.x - radius
        InnerRectF!!.bottom = centerPoint!!.y + radius
        InnerRectF!!.right = centerPoint!!.x + radius
        val lg = LinearGradient(InnerRectF!!.left, InnerRectF!!.top, InnerRectF!!.right, InnerRectF!!.bottom, Color.parseColor(progressStartColor), Color.parseColor(progressEndColor), Shader.TileMode.MIRROR)
        mProgressPaint!!.setShader(lg)
    }

    fun setCenterPoint(x: Float, y: Float) {
        Log.e("TEST", "setCenterPoint$x   $y")
        if (centerPoint == null) {
            centerPoint = PointF()
        }
        centerPoint!!.x = x
        centerPoint!!.y = y
        initRectF()
        postInvalidate()
    }

    fun setProgress(progress: Int) {
        this.progress = progress
        postInvalidate()
    }

    fun setPaintWidth(paintWidth: Float) {
        Log.e("TEST", "setPaintWidth$paintWidth")
        this.paintWidth = paintWidth
    }

}